@@ -1,4 +1,4 @@
-import { Component, OnInit } from "@angular/core"
+import { Component, OnInit } from "@angular/core";
 
 let exampleDocMod = `
     {
@@ -10,17 +10,14 @@ let exampleDocMod = `
             rating: "11kV"
         }
     }
-`
+`;
 
 @Component({
     selector: "docDb-admin",
-    templateUrl: "docDb.component.html"
+    templateUrl: "docDb.component.html",
 })
 export class DocDbComponent implements OnInit {
-    
-    exampleDoc = exampleDocMod
-    
-    ngOnInit() {
-    
-    }
+    exampleDoc = exampleDocMod;
+
+    ngOnInit() {}
 }
