@@ -1,6 +1,8 @@
 import logging
 from typing import Optional
 
+from vortex.Tuple import Tuple
+
 from peek_abstract_chunked_index.private.server.client_handlers.ACIChunkLoadRpcABC import (
     ACIChunkLoadRpcABC,
 )
@@ -33,7 +35,7 @@ class ClientChunkLoadRpc(ACIChunkLoadRpcABC):
         additionalFilt=docDbFilt,
         deferToThread=True,
     )
-    def loadDocumentChunks(self, offset: int, count: int) -> Optional[bytes]:
+    def loadDocumentChunks(self, offset: int, count: int) -> str:
         """Update Page Loader Status
 
         Tell the server of the latest status of the loader
