@@ -3,8 +3,7 @@ from typing import Union
 
 from twisted.internet.defer import Deferred, inlineCallbacks
 
-from peek_core_docdb._private.server.controller.StatusController import \
-    StatusController
+from peek_core_docdb._private.server.controller.StatusController import StatusController
 from vortex.Payload import Payload
 from vortex.TupleSelector import TupleSelector
 from vortex.handler.TupleDataObservableHandler import TuplesProviderABC
@@ -17,8 +16,9 @@ class AdminStatusTupleProvider(TuplesProviderABC):
         self._statusController = statusController
 
     @inlineCallbacks
-    def makeVortexMsg(self, filt: dict,
-                      tupleSelector: TupleSelector) -> Union[Deferred, bytes]:
+    def makeVortexMsg(
+        self, filt: dict, tupleSelector: TupleSelector
+    ) -> Union[Deferred, bytes]:
         tuples = [self._statusController.status]
 
         payloadEnvelope = yield Payload(filt, tuples=tuples).makePayloadEnvelopeDefer()
