@@ -11,19 +11,22 @@ from peek_core_docdb._private.storage.DocDbDocument import DocDbDocument
 
 logger = logging.getLogger(__name__)
 
+
 class DocumentTupleProvider(TuplesProviderABC):
     def __init__(self, ormSessionCreator):
         self._ormSessionCreator = ormSessionCreator
 
     @deferToThreadWrapWithLogger(logger)
-    def makeVortexMsg(self, filt: dict,
-                      tupleSelector: TupleSelector) -> Union[Deferred, bytes]:
+    def makeVortexMsg(
+        self, filt: dict, tupleSelector: TupleSelector
+    ) -> Union[Deferred, bytes]:
         # Potential filters can be placed here.
         # val1 = tupleSelector.selector["val1"]
 
         session = self._ormSessionCreator()
         try:
-            tasks = (session.query(DocDbDocument)
+            tasks = (
+                session.query(DocDbDocument)
                 # Potentially filter the results
                 # .filter(DocumentTuple.val1 == val1)
                 .all()
